#ifndef NT2_CORE_INCLUDE_FUNCTIONS_INNER_FOLD_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_INNER_FOLD_HPP_INCLUDED

#include <nt2/core/functions/inner_fold.hpp>
#include <nt2/core/functions/scalar/inner_fold.hpp>
#include <nt2/core/functions/shared_memory/inner_fold.hpp>
#include <nt2/core/functions/simd/inner_fold.hpp>

#endif
